@@ -1,7 +1,7 @@
 """
 Type annotations for codestar-notifications service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/type_defs/)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/type_defs.html)
 
 Usage::
 
@@ -15,8 +15,6 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Mapping, Sequence
 
-from typing_extensions import NotRequired
-
 from .literals import (
     DetailTypeType,
     ListEventTypesFilterNameType,
@@ -42,17 +40,14 @@ __all__ = (
     "DescribeNotificationRuleResultTypeDef",
     "EventTypeSummaryTypeDef",
     "ListEventTypesFilterTypeDef",
-    "ListEventTypesRequestListEventTypesPaginateTypeDef",
     "ListEventTypesRequestRequestTypeDef",
     "ListEventTypesResultTypeDef",
     "ListNotificationRulesFilterTypeDef",
-    "ListNotificationRulesRequestListNotificationRulesPaginateTypeDef",
     "ListNotificationRulesRequestRequestTypeDef",
     "ListNotificationRulesResultTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
     "ListTagsForResourceResultTypeDef",
     "ListTargetsFilterTypeDef",
-    "ListTargetsRequestListTargetsPaginateTypeDef",
     "ListTargetsRequestRequestTypeDef",
     "ListTargetsResultTypeDef",
     "NotificationRuleSummaryTypeDef",
@@ -186,15 +181,6 @@ ListEventTypesFilterTypeDef = TypedDict(
     },
 )
 
-ListEventTypesRequestListEventTypesPaginateTypeDef = TypedDict(
-    "ListEventTypesRequestListEventTypesPaginateTypeDef",
-    {
-        "Filters": Sequence["ListEventTypesFilterTypeDef"],
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
 ListEventTypesRequestRequestTypeDef = TypedDict(
     "ListEventTypesRequestRequestTypeDef",
     {
@@ -222,15 +208,6 @@ ListNotificationRulesFilterTypeDef = TypedDict(
     },
 )
 
-ListNotificationRulesRequestListNotificationRulesPaginateTypeDef = TypedDict(
-    "ListNotificationRulesRequestListNotificationRulesPaginateTypeDef",
-    {
-        "Filters": Sequence["ListNotificationRulesFilterTypeDef"],
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
 ListNotificationRulesRequestRequestTypeDef = TypedDict(
     "ListNotificationRulesRequestRequestTypeDef",
     {
@@ -273,15 +250,6 @@ ListTargetsFilterTypeDef = TypedDict(
     },
 )
 
-ListTargetsRequestListTargetsPaginateTypeDef = TypedDict(
-    "ListTargetsRequestListTargetsPaginateTypeDef",
-    {
-        "Filters": Sequence["ListTargetsFilterTypeDef"],
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
 ListTargetsRequestRequestTypeDef = TypedDict(
     "ListTargetsRequestRequestTypeDef",
     {
